=====================================
``psyclone.psyir.nodes.scoping_node``
=====================================

.. automodule:: psyclone.psyir.nodes.scoping_node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.scoping_node


Classes
=======

- :py:class:`ScopingNode`:
  Abstract node that has an associated Symbol Table to keep track of


.. autoclass:: ScopingNode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ScopingNode
      :parts: 1
